part of fullauth_api_flutter_client_library;

class TokenResponseException extends IOException {
  String errorMessage;
  OauthTokenErrorResponse errorResponse;

  TokenResponseException.errorMessage(String message) {
    this.errorMessage = message;
    this.errorResponse = null;
  }

  TokenResponseException.errorResponse(OauthTokenErrorResponse error) {
    this.errorResponse = error;
  }

  String toString() {
    if (this.getErrorResponse() != null) {
      return this.getErrorResponse().toString();
    } else {
      return "TokenResponseException(message=$errorMessage)";
    }
  }

  OauthTokenErrorResponse getErrorResponse() {
    return this.errorResponse;
  }
}

class IllegalArgumentException implements Exception {
  String _message;
  IllegalArgumentException({String message}) {
    this._message = message;
  }
  @override
  String toString() {
    return _message;
  }
}

class OauthTokenErrorResponse {
  String error;
  String errorDescription;
  String errorUri;

  OauthTokenErrorResponse({this.error, this.errorDescription});

  OauthTokenErrorResponse.fromJson(Map<String, dynamic> json) {
    error = json['error'];
    errorDescription = json['error_description'];
    errorUri = json['error_uri'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['error'] = this.error;
    data['error_description'] = this.errorDescription;
    data['error_uri'] = this.errorUri;
    return data;
  }

  String getErrorUri() {
    return this.errorUri;
  }

  String getErrorDesc() {
    return this.errorDescription;
  }

  void setErrorDesc(String errorDesc) {
    this.errorDescription = errorDesc;
  }

  void setErrorUri(String errorUri) {
    this.errorUri = errorUri;
  }

  String toString() {
    return "OauthTokenErrorResponse(error=$error" + ", errorDesc=$errorDescription" + ", errorUri= $errorUri)";
  }
}
